# PowerBeatsVR_song_writer
Convert a BeatSaber level in to a PowerBeatsVR level.
Currently does not work. Because something in the PowerBeatsVR format makes no sense.


## Usage

```
pip3 install powerbeatsvr
powerbeatsvr [beat saber zip map] [output folder (created)]
```

Place the generated json in the PowerBeatsVR layouts folder, and play the ogg file in the game.
